TouchstoneError

Enum TouchstoneError 

#[non_exhaustive]
pub enum TouchstoneError {
Show 20 variants Parse { context: TouchstoneErrorContext, source: Box<TouchstoneError>, }, Io(Error), InvalidUtf8(Utf8Error), MissingFileType { source_name: String, }, UnsupportedFileType { file_type: String, }, InvalidPortCount { file_type: String, }, MultipleOptionLines, InvalidDataLineParts { expected: usize, actual: usize, }, InvalidNumber { token: String, }, UnsupportedFrequencyUnit { unit: String, }, UnsupportedFormat { format: String, }, InvalidKeywordLine { line: String, }, UnsupportedVersion { version: String, }, InvalidNumberOfPorts { value: String, }, NumberOfPortsMismatch { keyword_ports: i32, extension_ports: i32, }, TwoPortDataOrderForNonTwoPort, UnsupportedTwoPortDataOrder { order: String, }, InvalidNumberOfFrequencies { value: String, }, NumberOfFrequenciesMismatch { expected: usize, actual: usize, }, UnsupportedMatrixFormat { format: String, },
}
Error returned when Touchstone data cannot be read or parsed.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Parse

A parse error with source-location context.

Fields

context: TouchstoneErrorContext

Source location where the parser detected the error.

source: Box<TouchstoneError>

Structured root error.



Io(Error)

The source file could not be read.



InvalidUtf8(Utf8Error)

In-memory bytes were not valid UTF-8 Touchstone text.



MissingFileType

The source name did not include a file extension.

Fields

source_name: String

Source name used for extension inference.



UnsupportedFileType

The source extension is not a supported Touchstone file type.

Fields

file_type: String

Unsupported extension without the leading dot.



InvalidPortCount

The Touchstone extension did not contain a valid port count.

Fields

file_type: String

Extension that could not be converted to a port count.



MultipleOptionLines

The file contained more than one option line.



InvalidDataLineParts

A data line did not contain the expected number of values.

Fields

expected: usize

Number of values required for the current network rank.

actual: usize

Number of values found in the line.



InvalidNumber

A numeric token could not be parsed as f64.

Fields

token: String

Token that failed numeric parsing.



UnsupportedFrequencyUnit

The frequency unit is not supported.

Fields

unit: String

Unit token from the option line.



UnsupportedFormat

The network data format is not supported.

Fields

format: String

Format token from the option line.



InvalidKeywordLine

A keyword line was malformed.

Fields

line: String

Full keyword line.



UnsupportedVersion

The Touchstone version is not supported.

Fields

version: String

Version string from the [Version] keyword.



InvalidNumberOfPorts

The [Number of Ports] value was not a valid integer.

Fields

value: String

Raw value from the keyword.



NumberOfPortsMismatch

The [Number of Ports] value did not match the source extension.

Fields

keyword_ports: i32

Port count declared by the keyword.

extension_ports: i32

Port count inferred from the source extension.



TwoPortDataOrderForNonTwoPort

[Two-Port Data Order] was present for a network other than .s2p.



UnsupportedTwoPortDataOrder

The [Two-Port Data Order] value is not supported.

Fields

order: String

Order token from the keyword.



InvalidNumberOfFrequencies

The [Number of Frequencies] value was not a valid integer.

Fields

value: String

Raw value from the keyword.



NumberOfFrequenciesMismatch

The parsed data line count did not match [Number of Frequencies].

Fields

expected: usize

Expected number of frequency rows.

actual: usize

Parsed number of frequency rows.



UnsupportedMatrixFormat

Matrix format values other than Full are not supported.

Fields

format: String

Matrix format token from the keyword.

Implementations

Source

impl TouchstoneError

pub fn context(&self) -> Option<&TouchstoneErrorContext>

Return parser source-location context when this error has it.

Examples
let error =
    touchstone::Network::from_str("uploaded.s1p", "# GHz S RI R 50\n1.0 0.1\n")
        .unwrap_err();

let context = error.context().unwrap();
assert_eq!(context.source_name, "uploaded.s1p");
assert_eq!(context.line_number, Some(2));
assert_eq!(context.line.as_deref(), Some("1.0 0.1"));
pub fn root_cause(&self) -> &TouchstoneError

Return the deepest structured error wrapped by parser context.

Examples
use touchstone::{Network, TouchstoneError};

let error = Network::from_str("uploaded.s1p", "# GHz S RI R 50\n1.0 0.1\n").unwrap_err();

assert!(matches!(
    error.root_cause(),
    TouchstoneError::InvalidDataLineParts {
        expected: 3,
        actual: 2
    }
));